"""
web2ldap plugin classes for OpenLDAP

$Id: openldap.py,v 1.9 2007/10/14 23:20:31 michael Exp $
"""

from w2lapp.schema.syntaxes import DistinguishedName,DirectoryString,Uri,syntax_registry

import ldap.filter
import w2lapp.gui

class EntryCSN(DirectoryString):
  oid = '1.3.6.1.4.1.4203.666.1.7'
  desc = 'OpenLDAP EntryCSN'


class AuditContext(DistinguishedName):
  oid = 'AuditContext'
  desc = 'OpenLDAP DN pointing to audit naming context'

  def displayValue(self,valueindex=0,commandbutton=0):
    r = [w2lapp.gui.DisplayDN(sid,form,ls,self.attrValue,commandbutton=0)]
    if commandbutton:
      r.extend([
	form.applAnchor('read','Read',sid,[('dn',self.attrValue)]),
	form.applAnchor(
	  'search','Audit trail',sid,
          [
            ('dn',self.attrValue),
            ('search_filterstr','(reqDN=%s)' % (ldap.filter.escape_filter_chars(dn))),
            ('scope',str(ldap.SCOPE_ONELEVEL)),
          ],
          title='Display audit trail for current entry',
	)
      ])
    return ' | '.join(r)

syntax_registry.registerAttrType(
  AuditContext.oid,['1.3.6.1.4.1.4203.666.11.5.1.30'] # auditContext
)

# Register all syntax classes in this module
for symbol_name in dir():
  syntax_registry.registerSyntaxClass(eval(symbol_name))

syntax_registry.registerAttrType(
  DistinguishedName.oid,[
    'entryDN','monitorConnectionAuthzDN',
    'configContext','monitorContext','reqDN','reqAuthzID'
  ]
)

syntax_registry.registerAttrType(
  Uri.oid,['monitorConnectionListener']
)

